@@ -18,8 +18,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: FileHandle.pm,v 1.1 2003/09/28 11:50:45 rwmj Exp $
-
 =pod
 
 =head1 NAME
@@ -30,12 +28,8 @@ Net::FTPServer::Full::FileHandle - The full FTP server personality
 
   use Net::FTPServer::Full::FileHandle;
 
-=head1 DESCRIPTION
-
 =head1 METHODS
 
-=over 4
-
 =cut
 
 package Net::FTPServer::Full::FileHandle;
@@ -43,7 +37,7 @@ package Net::FTPServer::Full::FileHandle;
 use strict;
 
 use vars qw($VERSION);
-( $VERSION ) = '$Revision: 1.1 $ ' =~ /\$Revision:\s+([^\s]+)/;
+( $VERSION ) = '$Revision: 1.2 $ ' =~ /\$Revision:\s+([^\s]+)/;
 
 use Net::FTPServer::FileHandle;
 
@@ -53,6 +47,8 @@ use vars qw(@ISA);
 
 =pod
 
+=over 4
+
 =item $dirh = $fileh->dir;
 
 Return the directory which contains this file.
@@ -74,7 +70,7 @@ sub dir
 =item $fh = $fileh->open (["r"|"w"|"a"]);
 
 Open a file handle (derived from C<IO::Handle>, see
-L<IO::Handle(3)>) in either read or write mode.
+C<IO::Handle(3)>) in either read or write mode.
 
 =cut
 
@@ -120,7 +116,7 @@ sub status
     # If the file has been removed since we created this
     # handle, then $dev will be undefined. Return dummy status
     # information.
-    return ("f", 0000, 1, "-", "-", 0, 0) unless $dev;
+    return ("f", 0000, 1, "-", "-", 0, 0) unless defined $dev;
 
     # Generate printable user/group.
     my $user = getpwuid ($uid) || "-";
@@ -210,7 +206,7 @@ sub readlink
 
 __END__
 
-=back 4
+=back
 
 =head1 AUTHORS
 
@@ -223,6 +219,6 @@ London, SW6 3EG, UK
 
 =head1 SEE ALSO
 
-L<Net::FTPServer(3)>, L<perl(1)>
+C<Net::FTPServer(3)>, C<perl(1)>
 
 =cut
