@@ -26,7 +26,7 @@ Net::FTPServer::InMem::Server - Store files in local memory
 
 =head1 SYNOPSIS
 
-  inmem-ftpd [-d] [-v] [-p port] [-s] [-S] [-V] [-C conf_file]
+  inmem-ftpd.pl [-d] [-v] [-p port] [-s] [-S] [-V] [-C conf_file]
 
 =head1 DESCRIPTION
 
@@ -109,17 +109,6 @@ sub root_directory_hook
 
 __END__
 
-=head1 FILES
-
-  /etc/ftpd.conf
-  /usr/lib/perl5/site_perl/5.005/Net/FTPServer.pm
-  /usr/lib/perl5/site_perl/5.005/Net/FTPServer/DirHandle.pm
-  /usr/lib/perl5/site_perl/5.005/Net/FTPServer/FileHandle.pm
-  /usr/lib/perl5/site_perl/5.005/Net/FTPServer/Handle.pm
-  /usr/lib/perl5/site_perl/5.005/Net/FTPServer/InMem/Server.pm
-  /usr/lib/perl5/site_perl/5.005/Net/FTPServer/InMem/DirHandle.pm
-  /usr/lib/perl5/site_perl/5.005/Net/FTPServer/InMem/FileHandle.pm
-
 =head1 AUTHORS
 
 Richard Jones (rich@annexia.org).
